﻿using System;
using System.Threading;
using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;
using SecretLabs.NETMF.Hardware;
using SecretLabs.NETMF.Hardware.NetduinoPlus;

using Microtoolskit.Hardware.Sensors;
using Microtoolskit.Hardware.Displays;

namespace MiniSerreV1
{
    public class Program
    {
        public static void Main()
        {
            // Constantes 
            const float temperatureConsigne = 22;

            // Variables
            float temperature = 0;
            float ecart = 0.2f;
            bool ActiveAlarme = false;

            // Configuration des entrées, sorties (Création des objets)       
            OutputPort CdeChauffage = new OutputPort(Pins.GPIO_PIN_D6, false); // CdeChauffage
            PWM Alarme = new PWM(PWMChannels.PWM_PIN_D5, 2000, 0.5, false); // Alarme à créer
            ELCD162 Lcd = new ELCD162(); //Lcd à créer
            TMP102 ModuleMesureTemp = new TMP102();

            // Initialisations
            ModuleMesureTemp.Init(); // Réglage de l'adresse
            Lcd.Init(); Lcd.ClearScreen(); Lcd.CursorOff();
            temperature = ModuleMesureTemp.ReadAsCelcius(); // Lecture de la température
            Lcd.PutString("Temp=" + temperature.ToString("F1") + "degC");

            while (true)
            {
                temperature = ModuleMesureTemp.ReadAsCelcius(); // Lecture de la température

                Lcd.ClearScreen(); // Effacer l'écran
                Lcd.PutString("Temp=" + temperature.ToString("F1") + "degC"); // Afficher la température sur l'écran

                if (temperature >= temperatureConsigne + ecart)
                {
                    CdeChauffage.Write(false);
                    ActiveAlarme = true;
                }
                else if (temperature <= temperatureConsigne - ecart)
                {
                    CdeChauffage.Write(true);
                }

                if (ActiveAlarme == true)
                {
                    if ((temperature >= temperatureConsigne - 0.5) && (temperature <= temperatureConsigne + 0.5))
                    {
                        Alarme.Stop();
                    }
                    else
                    {
                        Alarme.Start();
                    }

                }

                Thread.Sleep(1000); // Attendre une seconde entre chaque mesure+
            }
        }
    }
}
